@@ -17,14 +17,14 @@ from collections import OrderedDict
 import functools
 import re
 from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,13 +33,14 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation as gac_operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.appengine_admin_v1.types import appengine
-from google.cloud.appengine_admin_v1.types import application
-from google.cloud.appengine_admin_v1.types import operation as ga_operation
 from google.protobuf import duration_pb2  # type: ignore
-from .transports.base import ApplicationsTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import ApplicationsGrpcAsyncIOTransport
+
+from google.cloud.appengine_admin_v1.types import appengine, application
+from google.cloud.appengine_admin_v1.types import operation as ga_operation
+
 from .client import ApplicationsClient
+from .transports.base import DEFAULT_CLIENT_INFO, ApplicationsTransport
+from .transports.grpc_asyncio import ApplicationsGrpcAsyncIOTransport
 
 
 class ApplicationsAsyncClient:
