@@ -17,27 +17,28 @@ from collections import OrderedDict
 import functools
 import re
 from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
 except AttributeError:  # pragma: NO COVER
     OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
-from google.cloud.appengine_admin_v1.services.authorized_certificates import pagers
-from google.cloud.appengine_admin_v1.types import appengine
-from google.cloud.appengine_admin_v1.types import certificate
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import AuthorizedCertificatesTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import AuthorizedCertificatesGrpcAsyncIOTransport
+
+from google.cloud.appengine_admin_v1.services.authorized_certificates import pagers
+from google.cloud.appengine_admin_v1.types import appengine, certificate
+
 from .client import AuthorizedCertificatesClient
+from .transports.base import DEFAULT_CLIENT_INFO, AuthorizedCertificatesTransport
+from .transports.grpc_asyncio import AuthorizedCertificatesGrpcAsyncIOTransport
 
 
 class AuthorizedCertificatesAsyncClient:
