@@ -17,14 +17,14 @@ from collections import OrderedDict
 import functools
 import re
 from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,18 +33,18 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation as gac_operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
-from google.cloud.appengine_admin_v1.services.versions import pagers
-from google.cloud.appengine_admin_v1.types import app_yaml
-from google.cloud.appengine_admin_v1.types import appengine
-from google.cloud.appengine_admin_v1.types import deploy
-from google.cloud.appengine_admin_v1.types import operation as ga_operation
-from google.cloud.appengine_admin_v1.types import version
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import empty_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import VersionsTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import VersionsGrpcAsyncIOTransport
+
+from google.cloud.appengine_admin_v1.services.versions import pagers
+from google.cloud.appengine_admin_v1.types import app_yaml, appengine, deploy
+from google.cloud.appengine_admin_v1.types import operation as ga_operation
+from google.cloud.appengine_admin_v1.types import version
+
 from .client import VersionsClient
+from .transports.base import DEFAULT_CLIENT_INFO, VersionsTransport
+from .transports.grpc_asyncio import VersionsGrpcAsyncIOTransport
 
 
 class VersionsAsyncClient:
