@@ -13,13 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
-from google.cloud.appengine_admin_v1.types import app_yaml
-from google.cloud.appengine_admin_v1.types import deploy
 from google.protobuf import duration_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
+import proto  # type: ignore
 
+from google.cloud.appengine_admin_v1.types import app_yaml, deploy
 
 __protobuf__ = proto.module(
     package="google.appengine.v1",
